
/* Chrysalide - Outil d'analyse de fichiers binaires
 * utils.h - prototypes pour les fonctions d'aisance vis à vis du format DWARF
 *
 * Copyright (C) 2008-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _FORMAT_DWARF_UTILS_H
#define _FORMAT_DWARF_UTILS_H


#include <stdbool.h>
#include <stdint.h>


#include "d_dwarf.h"



/* Lit une valeur Little Endian Base 128 signée. */
bool read_leb128(dwarf_format *, off_t *, int64_t *, bool);

/* Lit une valeur Little Endian Base 128 non signée. */
bool read_uleb128(dwarf_format *, off_t *, uint64_t *, bool);

/* Lit une valeur représentant une longueur d'unité. */
bool read_unit_length(dwarf_format *, off_t *, off_t *);

/* Lit une valeur non signée sur deux octets. */
bool read_uhalf(dwarf_format *, off_t *, uint16_t *);

/* Lit une valeur indiquant une position dans les abréviations. */
bool read_abbrev_offset(dwarf_format *, off_t *, off_t *);

/* Lit une valeur indiquant la taille des adresses mémoire. */
bool read_address_size(dwarf_format *, off_t *, uint8_t *);



#endif  /* _FORMAT_DWARF_UTILS_H */
